


#ifndef __GST_APP_ENUM_TYPES_H__
#define __GST_APP_ENUM_TYPES_H__

#include <gst/gst.h>

G_BEGIN_DECLS

/* enumerations from "/usr/src/ports/mingw64-i686-gstreamer1.0-plugins-base/mingw64-i686-gstreamer1.0-plugins-base-1.12.3-1.noarch/src/gst-plugins-base-1.12.3/gst-libs/gst/app/gstappsrc.h" */

GType gst_app_stream_type_get_type (void);
#define GST_TYPE_APP_STREAM_TYPE (gst_app_stream_type_get_type())
G_END_DECLS

#endif /* __GST_APP_ENUM_TYPES_H__ */



